@@ -1,5 +1,5 @@
 from django.views.generic import FormView
-from django.contrib.auth.forms import AuthenticationForm, UserCreationForm, UserChangeForm, PasswordChangeForm
+from django.contrib.auth.forms import UserCreationForm, UserChangeForm, PasswordChangeForm
 from django.http import HttpResponseRedirect
 from django.core.urlresolvers import reverse
 from django.contrib.auth import login as auth_login, authenticate
@@ -8,20 +8,22 @@ from django.contrib import messages
 from django.forms import HiddenInput
 from django.conf import settings
 
-from user.forms import ProfileForm
+from user.forms import SignInForm, ProfileForm
 
 from coffee.mixins import FormMixin
     
 class SignInView(FormView, FormMixin):
-    form_class = AuthenticationForm
+    form_class = SignInForm
     success_url = '/'
     
     def get_form(self, *args):
         form = super(SignInView, self).get_form(self.get_form_class())
         fields = form.fields
         
+        field = 'username' if 'username' in fields.keys() else 'email'
+        
         placeholders = {
-            'username': 'Username',
+            field: field.title(),
             'password': 'Password',
         }
         
